@@ -3,32 +3,30 @@ get_by <- function(
     draws,
     newdata,
     by,
-    column,
     byfun = NULL,
     verbose = TRUE,
     ...) {
 
-    if (is.null(by)) {
+    if (is.null(by) || isFALSE(by)) {
         out <- estimates
         attr(out, "posterior_draws") <- draws
         return(out)
     }
 
-    setnames(estimates, old = column, new = "estimate")
-
-    bycols <- sort(setdiff(
-        unique(c(colnames(estimates), colnames(newdata))),
-        c("rowid", "rowidcf", "estimate", "predicted", "predicted_lo", "predicted_hi", "dydx", "comparison")))
-    bycols <- paste(bycols, collapse = ", ")
-
     missing <- setdiff(setdiff(colnames(by), "by"), colnames(estimates))
     if (length(missing) > 0) {
         idx <- intersect(c("rowid", "rowidcf", missing), colnames(newdata))
         estimates <- merge(estimates, newdata[, idx], sort = FALSE, all.x = TRUE)
     }
 
-    # `by` data.frame
-    if (isTRUE(checkmate::check_data_frame(by))) {
+    if (isTRUE(by)) {
+        regex <- "^term$|^group$|^contrast$|^contrast_"
+        bycols <- grep(regex, colnames(estimates), value = TRUE)
+
+    } else if (isTRUE(checkmate::check_character(by))) {
+        bycols <- by
+
+    } else if (isTRUE(checkmate::check_data_frame(by))) {
         idx <- setdiff(intersect(colnames(estimates), colnames(by)), "by")
         # harmonize column types
         for (v in colnames(by)) {
@@ -40,10 +38,6 @@ get_by <- function(
         }
         estimates[by, by := by, on = idx]
         bycols <- "by"
-
-    # `by` vector
-    } else {
-        bycols <- by
     }
 
     if ("by" %in% colnames(estimates) && anyNA(estimates[["by"]])) {
@@ -62,7 +56,6 @@ get_by <- function(
             data = estimates,
             index = bycols,
             draws = draws,
-            column = "estimate",
             byfun = byfun)
 
     # frequentist
@@ -85,8 +78,9 @@ get_by <- function(
                 .(estimate = mean(estimate, na.rm = TRUE)),
                 by = bycols]
         }
+        idx <- intersect(bycols, colnames(estimates))
+        if (length(idx) > 0) data.table::setorderv(estimates, cols = bycols)
     }
 
-    setnames(estimates, old = "estimate", new = column)
     return(estimates)
 }
\ No newline at end of file
