@@ -87,10 +87,6 @@ print.marginaleffects <- function(x,
         out$contrast <- NULL
     }
 
-    if ("type" %in% colnames(out) && length(unique(out$type)) == 1) {
-        out$type <- NULL
-    }
-
     # rename
     dict <- c(
         "group" = "Group",
@@ -199,15 +195,15 @@ print.marginaleffects <- function(x,
     }
     cat("\n")
     # cat("Model type: ", attr(x, "model_type"), "\n")
-    if (!inherits(x, "hypotheses.summary") && isTRUE(getOption("marginaleffects_print_type", default = TRUE))) {
-        cat("Prediction type: ", attr(x, "type"), "\n")
-    }
-    ## This is tricky to extract nicely when transform_* are passed from avg_comparisons to comparisons. I could certainly figure it out, but at the same time, I don't think the print method should return information that is immediately visible from the call. This is different from `type`, where users often rely on the default value, which can change from model to model, so printing it is often
-    # if (!is.null(attr(x, "transform_pre_label"))) {
-    #     cat("Pre-transformation: ", paste(attr(x, "transform_pre_label"), collapse = ""), "\n")
+    # if (!inherits(x, "hypotheses.summary") && isTRUE(getOption("marginaleffects_print_type", default = TRUE))) {
+    #     cat("Prediction type: ", attr(x, "type"), "\n")
     # }
-    # if (!is.null(attr(x, "transform_post_label"))) {
-    #     cat("Post-transformation: ", paste(attr(x, "transform_post_label"), collapse = ""), "\n")
+    ## This is tricky to extract nicely when transform_* are passed from avg_comparisons to comparisons. I could certainly figure it out, but at the same time, I don't think the print method should return information that is immediately visible from the call. This is different from `type`, where users often rely on the default value, which can change from model to model, so printing it is often
+    # if (!is.null(attr(x, "comparison_label"))) {
+    #     cat("Pre-transformation: ", paste(attr(x, "comparison_label"), collapse = ""), "\n")
+    # }
+    # if (!is.null(attr(x, "transform_label"))) {
+    #     cat("Post-transformation: ", paste(attr(x, "transform_label"), collapse = ""), "\n")
     # }
     vg <- attr(x, "variables_grid")
     if (length(vg) > 0) {
