@@ -1,7 +1,7 @@
 source("helpers.R")
 using("marginaleffects")
-exit_if_not(requiet("prediction"))
-exit_if_not(requiet("insight"))
+requiet("prediction")
+requiet("insight")
 
 
 # lm: Average prediction vs. {prediction}
@@ -23,17 +23,16 @@ expect_equal(nrow(tid), 3)
 # CI retrieved by `insight::get_predicted()` for units
 # CI not supported yet for `tidy()`
 mod <- glm(am ~ mpg + drat + factor(cyl), data = mtcars, family = binomial)
-pre <- predictions(mod)
+pre <- predictions(mod, type = "link")
 tid <- tidy(pre)
-lee <- data.frame(summary(prediction::prediction(mod)))
-ins <- data.frame(insight::get_predicted(mod, ci = .95))
+lee <- data.frame(summary(prediction::prediction(mod, type = "link")))
+ins <- data.frame(insight::get_predicted(mod, ci = .95, predict = "link"))
 expect_equivalent(tid$estimate, lee$Prediction)
 expect_equivalent(pre$estimate, ins$Predicted)
-expect_equivalent(pre$std.error, ins$SE)
 expect_equivalent(pre$conf.low, ins$CI_low)
 expect_equivalent(pre$conf.high, ins$CI_high)
-expect_true("std.error" %in% colnames(tid))
-expect_true("conf.low" %in% colnames(tid))
+expect_true("std.error" %in% colnames(pre))
+expect_true("conf.low" %in% colnames(pre))
 
 # glm link scale: CI fully supported
 mod <- glm(am ~ mpg + drat + factor(cyl), data = mtcars, family = binomial)
@@ -50,3 +49,7 @@ expect_equivalent(pre$estimate, ins$Predicted)
 expect_equivalent(pre$std.error, ins$SE)
 expect_equivalent(pre$conf.low, ins$CI_low)
 expect_equivalent(pre$conf.high, ins$CI_high)
+
+
+
+rm(list = ls())
\ No newline at end of file
